#pragma once
#include <vector>

// To store a rectangular bounding box e.g. a tracking result for a frame
typedef struct
{
  float x=0,y=0,width=0,height=0;
} rect;
// Used to store single tracking or fusion results
typedef std::vector<rect>  track;
// A list of tracking results e.g. to store tracking results for different tracking algorithms
typedef std::vector<track> trackList;

// A list of tracking results with starting marker. Required to be able to compare to GT if the training data does not start from frame 1.
// For training we compare: trackingResult[frame] with annotation[frame + trackingResult.start-1] i.e. start = n means that the training data starts at frame n while the annotations start at frame 1. 
struct eTrackList
{
    trackList  data;
    int start;

    const track & operator[] ( int x ) const
    {
        return data[x];
    }
    track & operator[] ( int x )
    {
        return data[x];
    }
    int size() const
    {
        return data.size();
    }
};
// Required to store tracking results for several sequences (as training data).
// For the tracking sequences a 2 dimensional vector is used. The 2. (inner) dimension is required for the passes in TRE and SRE (see paper). If you do not have passes ignore it i.e. set the inner dimension to 1.
// Each eTracklist should contain tracking results for N tracking algorithms for a specific sequence (and specific pass) 
typedef std::vector<std::vector<eTrackList> > trackData;


